@@ -28,4 +28,4 @@ try:
     import datadog
     statsd = datadog.statsd
 except ModuleNotFoundError:
-    statsd = StatsdNullClient()
+    statsd = StatsdNullClient()  # type: ignore
